/*
 * ====================================================================
 *  Container.h
 *
 *  Window-owning container control class CAmarettoContainer
 *
 * Copyright (c) 2005-2009 Nokia Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

#ifndef __CONTAINER_H
#define __CONTAINER_H

#include <coecntrl.h>
#include <eikdef.h>
#include <eiklbx.h>
#include <eiklbo.h>
#include <aknnavi.h>
#include <aknnavide.h>
#include <akntabgrp.h>
#include "Python_appui.h"
#include "symbian_python_ext_util.h"

extern TBool touch_enabled_flag;
extern TBool virtual_d_pad_flag;

NONSHARABLE_CLASS(VirtualNaviKeys) : public CCoeControl
{
public:
  VirtualNaviKeys();
  virtual ~VirtualNaviKeys();
  virtual void ConstructL(const TRect& aRect,
                          const CCoeControl* aParent, CAmarettoAppUi* aAppui);
  void CalculateAndDrawGraphic(TBool aDrawKeys, CWindowGc *gc);
  TRect iSize, left, right, center, up, down, topleft, topright;
  TInt tlX, tlY, brX, brY;
  CArrayFix<TPoint>* left_triangle, *right_triangle, *up_triangle, *down_triangle, *center_rect;

private:
  const CCoeControl *myParent;
  CAmarettoAppUi* myAppui;
  virtual void HandlePointerEventL(const TPointerEvent& aPointerEvent);

};

NONSHARABLE_CLASS(CAmarettoContainer) : public CCoeControl, MCoeControlObserver
{
public:
  static CAmarettoContainer *NewL(const TRect& aRect);
  virtual ~CAmarettoContainer();
  
  TInt SetComponentL(CCoeControl* aComponent, 
		     CAmarettoCallback* aEventHandler=NULL, char *aControlName=NULL);
  void Refresh() {SizeChanged(); DrawNow();}
  void EnableTabsL(const CDesCArray* aTabTexts, CAmarettoCallback* aFunc);
  void SetActiveTab(TInt aIndex);
  void HandlePointerEventL(const TPointerEvent& aPointerEvent);
  void DisablePointerForwarding(TBool aValue);
  TInt CreateNaviKeys(CAmarettoAppUi* aAppui);
  void RefreshNaviKeys();
  void RemoveNaviKeys();
  VirtualNaviKeys *virtual_keys;
  CWindowGc *navi_keys_gc;
  CAmarettoAppUi* iAppui;
protected:
  void ConstructL(const TRect&);

private:
  void SizeChanged();
  TInt CountComponentControls() const {return (iTop ? 1 : 0);}
  CCoeControl* ComponentControl(TInt aIx) const {return ((aIx == 0) ? iTop : NULL);}
  void Draw(const TRect& aRect) const;
  TKeyResponse OfferKeyEventL(const TKeyEvent& aKeyEvent, TEventCode aType);
  void HandleControlEventL(CCoeControl*, TCoeEvent) {;}
  
private:
  CAknNavigationControlContainer* GetNaviPane() const;
  CAknNavigationDecorator* iDecoratedTabGroup;
  CAknTabGroup* iTabGroup;
  CCoeControl* iTop;
  CAmarettoCallback* iTabCallback;
  CAmarettoCallback* iEventCallback;
  TBool iPointerForwardDisabled;
  char *iTopControlName;
  TBool  naviKeysIsVisible;
};

#endif /* __CONTAINER_H */
